@@ -9,3 +9,5 @@ fi
 ( cd usr/share/doc/HTML/en/kmousetool ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kmouth ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kmouth ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/jovie ; rm -rf common )
+( cd usr/share/doc/HTML/en/jovie ; ln -sf /usr/share/doc/HTML/en/common common )
